@@ -44,7 +44,9 @@ class GSCNodeFunctionReceiver:
         self.oncnodefunction = oncnodefunction
 
     def startSocket(self):
-        asyncio.run(GSCNodeFunctionReceiverSocket.create(self.sio, self.gsdbs, self.oncnodefunction))
+        loop = asyncio.get_event_loop()
+        loop.run_until_complete(GSCNodeFunctionReceiverSocket.create(self.sio, self.gsdbs, self.oncnodefunction))
+        # asyncio.run(GSCNodeFunctionReceiverSocket.create(self.sio, self.gsdbs, self.oncnodefunction))
 
     async def sendcnodefunctionanswer(self, id, msg):
         await self.sio.emit("answer", {"id": id, "message": json.dumps(msg)})
@@ -86,12 +88,10 @@ class GSCNodeFunctionCaller:
         self.oncnodefunctionanswer = oncnodefunctionanswer
 
     def startSocket(self):
-        asyncio.run(GSCNodeFunctionCallerSocket.create(self.sio, self.gsdbs, self.oncnodefunctionanswer))
+        asyncio.run()
+        loop = asyncio.get_event_loop()
+        loop.run_until_complete(
+            GSCNodeFunctionCallerSocket.create(self.sio, self.gsdbs, self.oncnodefunctionanswer))
 
     async def sendcnodefunction(self, target, msg):
         await self.sio.emit("oncnodefunction", {"target": target, "message": json.dumps(msg)})
-
-
-
-
-
